@@ -144,7 +144,7 @@ void command_saveas(gpointer callback_data,guint callback_action,
 			g_free(label);
 			/* ɥ˥塼 */
 			menu_item=gtk_menu_item_new_with_label(command_open_file);
-			sub_menu=gtk_item_factory_get_widget(item_factory,
+			sub_menu=gtk_item_factory_get_widget(item_factory_menu,
 													_("<main>/ɥ(W)"));
 			glist=gtk_container_children(GTK_CONTAINER(sub_menu));
 			gtk_menu_insert(GTK_MENU(sub_menu),menu_item,
@@ -406,8 +406,8 @@ void command_copy(gpointer callback_data,guint callback_action,
 void command_paste(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-    gtk_selection_convert(window,clipboard_atom,
-					gdk_atom_intern("COMPOUND_TEXT",FALSE),GDK_CURRENT_TIME);
+	gtk_selection_convert(window,clipboard_atom,
+							gdk_atom_intern("TARGETS",FALSE),GDK_CURRENT_TIME);
 }
 
 
@@ -484,45 +484,16 @@ void command_valchr(gpointer callback_data,guint callback_action,
 void command_jump(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	gint sx,sy;
 	JMPDLG jmp;
 	TEXTWND *ptw;
-	GdkPoint cursor,select,top;
 
 	ptw=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	jmp.max=ptw->max-1;
-	jmp.cursor=ptw->cursor.y;
-	if (jump_dialog(&jmp) && ptw->cursor.y!=jmp.cursor) {
-		cursor=ptw->cursor;
-		select=ptw->select;
-		top=ptw->top;
-		sx=MAX(ptw->drawing->allocation.width/ptw->fontsize,1);
-		sy=MAX(ptw->drawing->allocation.height/(ptw->fontsize*2),1);
-		ptw->cursor.y=jmp.cursor;
-		if (ptw->cursor.x<ptw->top.x)
-			ptw->top.x=ptw->cursor.x;
-		else if (ptw->cursor.x-sx+1>ptw->top.x)
-			ptw->top.x=ptw->cursor.x-sx+1;
-		if (ptw->cursor.y<ptw->top.y)
-			ptw->top.y=ptw->cursor.y;
-		else if (ptw->cursor.y-sy+1>ptw->top.y)
-			ptw->top.y=ptw->cursor.y-sy+1;
-		move_text_window(ptw,&top);
-		if (ptw->select.x>=0) {
-			if (ptw->select.y==ptw->cursor.y
-						&& ptw->select.x==get_align_pos(&ptw->start,&ptw->off,
-								ptw->cursor.x,ptw->cursor.y,ptw->tab,FALSE)) {
-				ptw->select.x=-1;
-				clear_sel(ptw,&select,&cursor);
-				set_menu_bar(ptw);
-			} else {
-				clear_sel(ptw,&ptw->cursor,&cursor);
-			}
-		}
-		draw_caret(ptw,&cursor);
-	}
+	jmp.max=ptw->max;
+	jmp.cursor=ptw->cursor.y+1;
+	if (jump_dialog(&jmp) && ptw->cursor.y!=jmp.cursor-1)
+		jump_operation(ptw,jmp.cursor);
 }
 
 
