@@ -38,7 +38,8 @@ void set_history(gchar *file)
 	GList *glist;
 	GtkWidget *sub_menu,*menu_item;
 
-	sub_menu=gtk_item_factory_get_widget(item_factory,_("<main>/ե(F)"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
+													_("<main>/ե(F)"));
 	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
 	count=g_list_length(glist);
 	for (i=0;i<count-MENUFILE-1;i++) {
@@ -235,11 +236,12 @@ void open_text_file(TEXTWND *ptw)
 
 
 /*	ե򳫤
-	file,ե̾															*/
-void open_edit_file(gchar *file)
+	file,ե̾
+	 RET,TXTɥ													*/
+TEXTWND *open_edit_file(gchar *file)
 {
 	gchar *ext,*p,*label;
-	gint i,fontsize,lbearing,rbearing,width,ascent,descent;
+	gint i,leng0,leng1,fontsize,lbearing,rbearing,width,ascent,descent;
 	TEXTWND *ptw;
 	GtkWidget *table,*sub_menu;
 	static gint fcount=0;	/* եο */
@@ -256,15 +258,7 @@ void open_edit_file(gchar *file)
 	ptw->ic_attr=NULL;
 	if (file==NULL) {
 		/*  */
-		ext=g_strdup(ftype[0].ext);
-		if (ext==NULL) {
-			ptw->file=g_strdup_printf("new%04d",fcount++%1000);
-		} else {
-			for (i=0;ext[i]!='\0' && ext[i]!=';';i++);
-			ext[i]='\0';
-			ptw->file=g_strdup_printf("new%04d.%s",fcount++%1000,ext);
-			g_free(ext);
-		}
+		ptw->file=g_strdup_printf("new%04d",fcount++%1000);
 		ptw->create=TRUE;
 		ptw->margin=ftype[0].margin;
 		ptw->tab=ftype[0].tab;
@@ -282,16 +276,17 @@ void open_edit_file(gchar *file)
 		memcpy(ptw->color,ftype[0].color,sizeof(GdkColor)*12);
 	} else {
 		ptw->file=g_strdup(file);
-		ext=strrchr(ptw->file,'.');
-		if (ext!=NULL) {
-			ext++;
-			for (i=0;i<ftnum;i++) {
-				if (strcmp(ftype[i].ext,"*")==0)
-					break;
-				for (p=strtok(ftype[i].ext,";");p!=NULL;p=strtok(NULL,";"))
-					if (strcmp(ext,p)==0)
-						goto loop;
+		leng0=strlen(ptw->file);
+		for (i=0;i<ftnum;i++) {
+			if (strcmp(ftype[i].ext,"*")==0)
+				break;
+			ext=g_strdup(ftype[i].ext);
+			for (p=strtok(ext,";");p!=NULL;p=strtok(NULL,";")) {
+				leng1=strlen(p);
+				if (leng0>=leng1 && strcmp(ptw->file+leng0-leng1,p)==0)
+					goto loop;
 			}
+			g_free(ext);
 		}
 		loop:
 		if (i>=ftnum)
@@ -382,7 +377,7 @@ void open_edit_file(gchar *file)
 							GTK_FILL,GTK_EXPAND | GTK_SHRINK | GTK_FILL,0,0);
 	gtk_object_set_user_data(GTK_OBJECT(table),ptw);
 	/* ˥塼 */
-	sub_menu=gtk_item_factory_get_widget(item_factory,
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
 													_("<main>/ɥ(W)"));
 	ptw->menu_item=gtk_menu_item_new_with_label(ptw->file);
 	gtk_signal_connect(GTK_OBJECT(ptw->menu_item),"activate",
@@ -401,6 +396,8 @@ void open_edit_file(gchar *file)
 	/* ǤϤʤե뤬¸ߤˤ˲ä */
 	if (file!=NULL && history>0 && isfile(file))
 		set_history(file);
+
+	return ptw;
 }
 
 
