@@ -119,32 +119,32 @@ void set_menu_bar(TEXTWND *ptw)
 
 	if (ptw!=NULL) {
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
-									gtk_item_factory_get_widget(item_factory,
+								gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/Խ(E)")))),TRUE);
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
-									gtk_item_factory_get_widget(item_factory,
+								gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/(S)")))),TRUE);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/ե(F)/Ĥ(C)")),TRUE);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/ե(F)/¸(S)")),TRUE);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/ե(F)/̾Ĥ¸(A)...")),TRUE);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/ե(F)/¸Ƥ֤᤹(R)...")),TRUE);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/ե(F)/ץѥƥ(I)...")),TRUE);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/Խ(E)/᤹(U)")),ptw->undo!=NULL);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/Խ(E)/ľ(R)")),ptw->redo!=NULL);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/Խ(E)/ڤ(T)")),ptw->select.x>=0);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/Խ(E)/ԡ(C)")),ptw->select.x>=0);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/Խ(E)/(L)")),ptw->select.x>=0);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/(S)/򸡺(N)")),find_num>0);
 		gtk_widget_set_sensitive(toolbar_items[ 2].item,TRUE);
 		gtk_widget_set_sensitive(toolbar_items[ 4].item,TRUE);
@@ -159,20 +159,20 @@ void set_menu_bar(TEXTWND *ptw)
 		gtk_widget_set_sensitive(toolbar_items[17].item,TRUE);
 	} else {
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
-									gtk_item_factory_get_widget(item_factory,
+								gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/Խ(E)")))),FALSE);
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
-									gtk_item_factory_get_widget(item_factory,
+								gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/(S)")))),FALSE);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/ե(F)/Ĥ(C)")),FALSE);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/ե(F)/¸(S)")),FALSE);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/ե(F)/̾Ĥ¸(A)...")),FALSE);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/ե(F)/¸Ƥ֤᤹(R)...")),FALSE);
-		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory,
+		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/ե(F)/ץѥƥ(I)...")),FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 2].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 4].item,FALSE);
@@ -186,7 +186,8 @@ void set_menu_bar(TEXTWND *ptw)
 		gtk_widget_set_sensitive(toolbar_items[15].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[17].item,FALSE);
 	}
-	menu=gtk_item_factory_get_widget(item_factory,_("<main>/ɥ(W)"));
+	menu=gtk_item_factory_get_widget(item_factory_menu,
+													_("<main>/ɥ(W)"));
 	glist=gtk_container_children(GTK_CONTAINER(menu));
 	gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(menu)),
 													g_list_length(glist)>0);
@@ -661,3 +662,45 @@ void tab_operation(TEXTWND *ptw)
 	set_menu_bar(ptw);
 	gtk_widget_draw(ptw->drawing,NULL);
 }
+
+
+/*	Ԥذư
+	 ptw,TXTɥ
+	line,(1...)														*/
+void jump_operation(TEXTWND *ptw,gint line)
+{
+	gint sx,sy;
+	GdkPoint cursor,select,top;
+
+	cursor=ptw->cursor;
+	select=ptw->select;
+	top=ptw->top;
+	sx=MAX(ptw->drawing->allocation.width/ptw->fontsize,1);
+	sy=MAX(ptw->drawing->allocation.height/(ptw->fontsize*2),1);
+	ptw->cursor.y=line<0?ptw->max+line:line-1;
+	if (ptw->cursor.y<0)
+		ptw->cursor.y=0;
+	else if (ptw->cursor.y>ptw->max-1)
+		ptw->cursor.y=ptw->max-1;
+	if (ptw->cursor.x<ptw->top.x)
+		ptw->top.x=ptw->cursor.x;
+	else if (ptw->cursor.x-sx+1>ptw->top.x)
+		ptw->top.x=ptw->cursor.x-sx+1;
+	if (ptw->cursor.y<ptw->top.y)
+		ptw->top.y=ptw->cursor.y;
+	else if (ptw->cursor.y-sy+1>ptw->top.y)
+		ptw->top.y=ptw->cursor.y-sy+1;
+	move_text_window(ptw,&top);
+	if (ptw->select.x>=0) {
+		if (ptw->select.y==ptw->cursor.y
+						&& ptw->select.x==get_align_pos(&ptw->start,&ptw->off,
+								ptw->cursor.x,ptw->cursor.y,ptw->tab,FALSE)) {
+			ptw->select.x=-1;
+			clear_sel(ptw,&select,&cursor);
+			set_menu_bar(ptw);
+		} else {
+			clear_sel(ptw,&ptw->cursor,&cursor);
+		}
+	}
+	draw_caret(ptw,&cursor);
+}
