@@ -23,77 +23,78 @@
 #include "tmaid.h"
 
 
-/*	Lbg̕`
-	   ptw,TXTEChE
-	cursor,VJ[\ʒu												*/
+/*	åȤ
+	   ptw,TXTɥ
+	cursor,												*/
 void draw_caret(TEXTWND *ptw,GdkPoint *cursor);
 
 
-/*	j[ݒ肷
-	ptw,TXTEChE													*/
+/*	˥塼ꤹ
+	ptw,TXTɥ													*/
 void set_menu_bar(TEXTWND *ptw);
 
 
-/*	w͈͂ĕ`悷
-	ptw,TXTEChE
-	start,Jn
-	  end,I																*/
+/*	ϰϤ褹
+	ptw,TXTɥ
+	start,
+	  end,λ																*/
 void clear_sel(TEXTWND *ptw,GdkPoint *start,GdkPoint *end);
 
 
-/*	ړ
-	ptw,TXTEChE
-	top,Â̍W														*/
+/*	ư
+	ptw,TXTɥ
+	top,Ťκɸ														*/
 void move_text_window(TEXTWND *ptw,GdkPoint *top);
 
 
-/*	LbgʒuɃf[^}/㏑
-	   ptw,TXTEChE
-	  text,f[^i[|C^
-	length,f[^̃oCg
-	 caret,TRUE:ړ,FALSE:ړȂ
-	select,TRUE:I,FALSE:IȂ
-	   RET,t̑sDOING\,NULL:G[							*/
+/*	åȰ֤˥ǡ/񤭤
+	   ptw,TXTɥ
+	  text,ǡǼݥ
+	length,ǡΥХȿ
+	 caret,TRUE:ư,FALSE:ưʤ
+	select,TRUE:򤹤,FALSE:򤷤ʤ
+	   RET,դԤDOING¤,NULL:顼							*/
 DOING *edit_operation(TEXTWND *ptw,gchar *text,gint length,
 											gboolean caret,gboolean select);
 
 
-/*	E}[WŐ܂Ԃ
-	ptw,TXTEChE													*/
+/*	ޡޤ֤
+	ptw,TXTɥ													*/
 void modify_margin(TEXTWND *ptw);
 
 
-/*	t@CJ
-	file,t@C															*/
-void open_edit_file(gchar *file);
-
-
-/*	t@C̕ۑ₢킹
-	ptw,TXTEChE
-	RET,TRUE:t@C͕,FALSE:t@CȂ						*/
+/*	ե¸䤤碌
+	ptw,TXTɥ
+	RET,TRUE:եĤ,FALSE:եĤʤ						*/
 gboolean prompt_close(TEXTWND *ptw);
 
 
-/*	Xg폜
-	  d,Xg̐擪
-	RET,폜Xg̐													*/
+/*	ꥹȤ
+	  d,ꥹȤƬ
+	RET,ꥹȤο													*/
 gint delete_list(DOING **d);
 
 
-/*	ҏW𑀍
-	 ptw,TXTEChE
+/*	Խ
+	 ptw,TXTɥ
 	kind,TRUE:redo,FALSE:undo												*/
 void history_operation(TEXTWND *ptw,gboolean kind);
 
 
-/*	E}[Wŉs
-	 ptw,TXTEChE													*/
+/*	ޡǲԤ
+	 ptw,TXTɥ													*/
 void margin_operation(TEXTWND *ptw);
 
 
-/*	^uXy[Xɕϊ
-	 ptw,TXTEChE													*/
+/*	֤򥹥ڡѴ
+	 ptw,TXTɥ													*/
 void tab_operation(TEXTWND *ptw);
 
 
+/*	Ԥذư
+	 ptw,TXTɥ
+	line,(1...)														*/
+void jump_operation(TEXTWND *ptw,gint line);
+
+
 #endif
