@@ -33,7 +33,11 @@ static GtkWidget *dialog;
 static GtkWidget *button0,*button3;
 static GtkWidget *check0,*check1,*check2,*check3,*check4;
 static GtkWidget *check5,*check6,*check7,*check8,*check9;
-static GtkWidget *entry0,*entry1,*spin0,*spin1;
+static GtkWidget *clist,*entry0,*entry1,*spin0,*spin1;
+static gchar *color_name[12]={N_("ʸ"),N_("ط"),N_("ȥ륳"),
+		N_("ѥڡ"),N_("ԥ"),N_("ֲ"),
+		N_("ޡ"),N_("å"),N_("򤵤줿ʸ"),
+		N_("򤵤줿ط"),N_("ʸ()"),N_("ȥ륳()")};
 
 
 /* OKܥɽ/ɽȽ */
@@ -46,19 +50,23 @@ static void property_dialog_ok_sensitive(GtkWidget *widget,gpointer user_data)
 
 
 /* ꥹȥܥå */
-static void property_dialog_select(GtkWidget *widget,gint pos)
+static void property_dialog_select_row(GtkWidget *widget,
+				gint row,gint column,GdkEventButton *event,gpointer user_data)
 {
-	color_list[pos]=TRUE;
+	color_list[row]=TRUE;
 	gtk_widget_set_sensitive(button0,TRUE);
 }
 
 
 /* ꥹȥܥå */
-static void property_dialog_deselect(GtkWidget *widget,gint pos)
+static void property_dialog_unselect_row(GtkWidget *widget,
+				gint row,gint column,GdkEventButton *event,gpointer user_data)
+
+
 {
 	gint i;
 
-	color_list[pos]=FALSE;
+	color_list[row]=FALSE;
 	for (i=0;i<12;i++)
 		if (color_list[i])
 			break;
@@ -70,17 +78,30 @@ static void property_dialog_deselect(GtkWidget *widget,gint pos)
 static void property_dialog_clicked_color_ok(GtkWidget *widget,
 													GtkWidget *dialog_color)
 {
+	gchar *xpm[18];
 	gint i;
 	gdouble color[4];
+	GdkPixmap *pixmap;
+	GdkBitmap *mask;
 
 	gtk_color_selection_get_color(GTK_COLOR_SELECTION(
 					GTK_COLOR_SELECTION_DIALOG(dialog_color)->colorsel),color);
-	for (i=0;i<12;i++)
+	xpm[0]="24 16 1 1";
+	for (i=2;i<18;i++)
+		xpm[i]="XXXXXXXXXXXXXXXXXXXXXXXX";
+	for (i=0;i<12;i++) {
 		if (color_list[i]) {
 			gdk_color[i].red=color[0]*0xffff;
 			gdk_color[i].green=color[1]*0xffff;
 			gdk_color[i].blue=color[2]*0xffff;
 		}
+		xpm[1]=g_strdup_printf("X\tc #%02X%02X%02X",
+			gdk_color[i].red/256,gdk_color[i].green/256,gdk_color[i].blue/256);
+		pixmap=gdk_pixmap_create_from_xpm_d(dialog->window,&mask,NULL,xpm);
+		g_free(xpm[1]);
+		gtk_clist_set_pixtext(GTK_CLIST(clist),i,0,
+												color_name[i],8,pixmap,mask);
+	}
 	property_dialog_ok_sensitive(NULL,NULL);
     gtk_widget_destroy(dialog_color);
 }
@@ -244,13 +265,12 @@ static gboolean property_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 
 gboolean property_dialog(FTYPE *ft)
 {
-	gchar *color_name[12]={N_("ʸ"),N_("ط"),N_("ȥ륳"),
-		N_("ѥڡ"),N_("ԥ"),N_("ֲ"),
-		N_("ޡ"),N_("å"),N_("򤵤줿ʸ"),
-		N_("򤵤줿ط"),N_("ʸ()"),N_("ȥ륳()")};
+	gchar *xpm[18];
 	gint i;
+	GdkPixmap *pixmap;
+	GdkBitmap *mask;
 	GtkWidget *button1,*button2,*button4;
-	GtkWidget *list,*item,*scroll,*hbox,*tbox,*vbox;
+	GtkWidget *hbox,*tbox,*vbox;
 	GtkWidget *frame0,*frame1,*frame2,*frame3,*frame4;
 
 	/* ᥤ󥦥ɥ */
@@ -260,7 +280,7 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 							GTK_SIGNAL_FUNC(property_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
-
+	gtk_widget_show(dialog);
 	/* ܥ */
 	button0=gtk_button_new_with_label(_("ѹ"));
 	button1=gtk_button_new_with_label(_("ե"));
@@ -340,22 +360,28 @@ gboolean property_dialog(FTYPE *ft)
 		entry0=entry1=NULL;
 	}
 	/* ꥹȥܥå */
-	list=gtk_list_new();
-	gtk_list_set_selection_mode(GTK_LIST(list),GTK_SELECTION_MULTIPLE);
+	clist=gtk_clist_new(1);
+	gtk_clist_column_titles_passive(GTK_CLIST(clist));
+	gtk_clist_set_selection_mode(GTK_CLIST(clist),GTK_SELECTION_MULTIPLE);
+	xpm[0]="24 16 1 1";
+	for (i=2;i<18;i++)
+		xpm[i]="XXXXXXXXXXXXXXXXXXXXXXXX";
 	for (i=0;i<12;i++) {
-		item=gtk_list_item_new_with_label(color_name[i]);
-		gtk_container_add(GTK_CONTAINER(list),item);
-		gtk_signal_connect(GTK_OBJECT(item),"select",
-										property_dialog_select,(gpointer)i);
-		gtk_signal_connect(GTK_OBJECT(item),"deselect",
-										property_dialog_deselect,(gpointer)i);
+		xpm[1]=g_strdup_printf("X\tc #%02X%02X%02X",
+			ft->color[i].red/256,ft->color[i].green/256,ft->color[i].blue/256);
+		pixmap=gdk_pixmap_create_from_xpm_d(dialog->window,&mask,NULL,xpm);
+		g_free(xpm[1]);
+		gtk_clist_append(GTK_CLIST(clist),&color_name[i]);
+		gtk_clist_set_pixtext(GTK_CLIST(clist),i,0,
+												color_name[i],8,pixmap,mask);
 		color_list[i]=FALSE;
 	}
-	/* 륦ɥ */
-	scroll=gtk_scrolled_window_new(NULL,NULL);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
-									GTK_POLICY_NEVER,GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scroll),list);
+	gtk_clist_set_column_width(GTK_CLIST(clist),0,
+						gtk_clist_optimal_column_width(GTK_CLIST(clist),0));
+	gtk_signal_connect(GTK_OBJECT(clist),"select-row",
+											property_dialog_select_row,NULL);
+	gtk_signal_connect(GTK_OBJECT(clist),"unselect-row",
+											property_dialog_unselect_row,NULL);
 	/* ԥܥ */
 	spin0=gtk_spin_button_new(
 		GTK_ADJUSTMENT(gtk_adjustment_new(ft->margin,1,G_MAXINT,1,5,0)),0,0);
@@ -431,7 +457,7 @@ gboolean property_dialog(FTYPE *ft)
 	frame4=gtk_frame_new(_(""));
 	vbox=gtk_vbox_new(FALSE,0);
 	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),scroll,TRUE,TRUE,8);
+	gtk_box_pack_start(GTK_BOX(hbox),clist,TRUE,TRUE,8);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox,TRUE,TRUE,8);
 	hbox=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,8);
