@@ -425,7 +425,7 @@ gboolean signal_button_press(GtkWidget *widget,
 	switch (event->type) {
 	case GDK_BUTTON_PRESS:
 		switch (event->button) {
-		case 1:
+		case 1:/* å */
 			{
 				gboolean shift;
 				GdkPoint cursor,select;
@@ -462,9 +462,20 @@ gboolean signal_button_press(GtkWidget *widget,
 				draw_caret(ptw,&cursor);
 			}
 			break;
-		case 3:
+		case 3:/* å */
+			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
+				item_factory_popup,_("<main>/᤹(U)")),ptw->undo!=NULL);
+			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
+				item_factory_popup,_("<main>/ڤ(T)")),ptw->select.x>=0);
+			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
+				item_factory_popup,_("<main>/ԡ(C)")),ptw->select.x>=0);
+			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
+				item_factory_popup,_("<main>/(L)")),ptw->select.x>=0);
+			gtk_menu_popup(GTK_MENU(
+					gtk_item_factory_get_widget(item_factory_popup,"<main>")),
+								NULL,NULL,NULL,NULL,event->button,event->time);
 			break;
-		case 4:
+		case 4:/* ۥ */
 		case 5:
 			{
 				gint max,sx,sy;
@@ -1033,7 +1044,7 @@ void signal_destroy_draw(GtkWidget *widget,TEXTWND *ptw)
 	/* ե̾Ĵ٤ */
 	delete_edit_file(ptw->file);
 	/* ɥ˥塼 */
-	sub_menu=gtk_item_factory_get_widget(item_factory,
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
 													_("<main>/ɥ(W)"));
 	gtk_container_remove(GTK_CONTAINER(sub_menu),ptw->menu_item);
 	/* ˥塼 */
@@ -1200,14 +1211,27 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 	gint i,count;
 	DOING *d;
 	TEXTWND *ptw;
+	GdkAtom *atoms;
 	GdkPoint select;
 
 	if (data->length>=0) {
-		if (data->type==GDK_TARGET_STRING) {
+		if (data->type==GDK_SELECTION_TYPE_ATOM) {
+			/* äȥ */
+			atoms=(GdkAtom *)data->data;
+			count=data->length/sizeof(GdkAtom);
+			for (i=0;i<count;i++)
+				if (atoms[i]==GDK_TARGET_STRING
+							|| atoms[i]==gdk_atom_intern("COMPOUND_TEXT",FALSE)
+							|| atoms[i]==gdk_atom_intern("TEXT",FALSE))
+					break;
+			if (i<count)
+				gtk_selection_convert(window,clipboard_atom,atoms[i],
+															GDK_CURRENT_TIME);
+		} else if (data->type==GDK_TARGET_STRING) {
 			data->data[data->length]='\0';
 			text=g_strdup(data->data);
 		} else if (data->type==gdk_atom_intern("COMPOUND_TEXT",FALSE)
-							   || data->type==gdk_atom_intern ("TEXT",FALSE)) {
+								|| data->type==gdk_atom_intern("TEXT",FALSE)) {
 			count=gdk_text_property_to_text_list(data->type,data->format,
 												data->data,data->length,&list);
 			if (count>0) {
@@ -1260,7 +1284,8 @@ void signal_destroy_window(GtkWidget *widget,gpointer user_data)
 	GtkWidget *sub_menu;
 
 	memset(hisfile,0,sizeof(gchar *)*10);
-	sub_menu=gtk_item_factory_get_widget(item_factory,_("<main>/ե(F)"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
+													_("<main>/ե(F)"));
 	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
 	for (i=0;i<(gint)g_list_length(glist)-MENUFILE-1;i++)
 		hisfile[i]=g_strdup(gtk_object_get_user_data(
