@@ -16,16 +16,17 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
+#include <ctype.h>
 #include <locale.h>
-#include <stdio.h>
+#include <stdlib.h>
 #include "tmaid.h"
-#include "argument.h"
 #include "command.h"
 #include "conf.h"
 #include "fileop.h"
 #include "find.h"
 #include "format.h"
 #include "general.h"
+#include "other.h"
 #include "profile.h"
 #include "replace.h"
 #include "signal.h"
@@ -33,10 +34,10 @@
 #include "version.h"
 
 
-gboolean newfile=FALSE;				/* TRUE:ե,FALSE:ʤ */
 gboolean caret=FALSE;				/* åȤη */
 gboolean ins=TRUE;					/* TRUE:,FALSE: */
 gboolean has_selection=FALSE;		/* TRUE:ͭ,FALSE:ʤ */
+gboolean newfile=FALSE;				/* TRUE:ե,FALSE:ʤ */
 gchar *hisfile[10];					/* ե */
 gchar *clipboard_text=NULL;			/* åץܡɤΥƥ */
 gint ftnum=0;						/* ե륿פο */
@@ -48,13 +49,13 @@ GdkAtom clipboard_atom;				/* åץܡ */
 GtkWidget *window;					/* ɥ */
 GtkWidget *notebook;				/* Ρȥ֥å */
 GtkWidget *status;					/* ơɥ */
-GtkItemFactory *item_factory;		/* ˥塼 */
+GtkItemFactory *item_factory_menu;	/* ˥塼 */
+GtkItemFactory *item_factory_popup;	/* ݥåץå */
 
 
-GtkTargetEntry drag_types[1]={{"text/uri-list",0,0}};
 GtkItemFactoryEntry menu_items[]={
 {N_("/ե(_F)"),                               NULL,         NULL,            0,"<Branch>"},
-{N_("/ե(F)/(_N)"),                   "<control>N", open_edit_file,  0,"<Item>"},
+{N_("/ե(F)/(_N)"),                   "<control>N", command_new,     0,"<Item>"},
 {N_("/ե(F)/(_O)..."),                    "<control>O", command_open,    0,"<Item>"},
 {N_("/ե(F)/Ĥ(_C)"),                     "<control>W", command_close,   0,"<Item>"},
 {N_("/ե(F)/¸(_S)"),                 "<control>S", command_save,    0,"<Item>"},
@@ -100,9 +101,12 @@ GtkItemFactoryEntry menu_items[]={
 ******************************************************************************/
 int main(int argc,char *argv[])
 {
-	gchar *section=NULL,*key=NULL;
-	gint i,remaining;
+	gboolean *arg_files;
+	gchar *arg,*endptr,*str,*section=NULL,*key=NULL;
+	gint i,j,k,opt;
+	gint init_line=0;					/* ΥåȰ */
 	PROFILE *profile;
+	TEXTWND *ptw;
 	GdkBitmap *mask;
 	GdkPixmap *pixmap;
 	GtkAccelGroup *accel_group;
@@ -113,10 +117,36 @@ int main(int argc,char *argv[])
 						{0,0x8000,0x8000,0x8000},{0,0xa000,0xa000,0xa000},
 						{0,0xffff,0xffff,0xffff},{0,0x0000,0x0000,0x8000},
 						{0,0x0000,0x0000,0x0000},{0,0x8000,0x8000,0x8000}};
+	GtkItemFactoryEntry popup_items[]={
+		{N_("/᤹(_U)"),  "<control>Z",command_undo,  0,"<Item>"},
+		{N_("/Sep1"),          NULL,        NULL,          0,"<Separator>"},
+		{N_("/ڤ(_T)"),  "<control>X",command_cut,   0,"<Item>"},
+		{N_("/ԡ(_C)"),    "<control>C",command_copy,  0,"<Item>"},
+		{N_("/Žդ(_P)"),  "<control>V",command_paste, 0,"<Item>"},
+		{N_("/(_L)"),      NULL,        command_delete,0,"<Item>"},
+		{N_("/Sep2"),          NULL,        NULL,          0,"<Separator>"},
+		{N_("/٤(_A)"),"<control>A",command_all,   0,"<Item>"}};
+	GtkTargetEntry drag_types[1]={{"text/uri-list",0,0}};
+	/* Text maid󶡲ǽʥ쥯 */
 	GtkTargetEntry targets[]={
 	{"STRING",       0,TARGET_STRING},
 	{"TEXT",         0,TARGET_TEXT}, 
 	{"COMPOUND_TEXT",0,TARGET_COMPOUND_TEXT}};
+	/* ޥɥ饤  */
+	struct arg_opt {
+		const char *name;
+		const int key;
+		const char *arg;
+		const char *doc;
+	};
+	const struct arg_opt arg_opts[]={
+	{"history",'h',"NUM",         N_("ե")},
+	{"line",   'l',"NUM",         N_("ΥåȰ")},
+	{"new",    'n',"ON/OFF",      N_("ե򳫤")},
+	{"size",   's',"WIDTH,HEIGHT",N_("ɥΥ")},
+	{"version",'v',NULL,          N_("С")},
+	{"help",   '?',NULL,          N_("إ")},
+	{NULL,     0,  NULL,          NULL}};
 
 	/*  */
 	setlocale(LC_ALL,"");
@@ -274,14 +304,89 @@ int main(int argc,char *argv[])
 	}
 
 	/* ޥɥ饤β */
-	argp_parse(&argp,argc,argv,0,&remaining,NULL);
+	arg_files=g_malloc(argc*sizeof(gboolean));
+	memset(arg_files,0,argc*sizeof(gboolean));
+	for (i=1;i<argc;i++) {
+		if ((argv[i])[0]=='-') {/* ץ */
+			if ((argv[i])[1]=='-') {	/* Ĺץ */
+				opt=0;
+				for (j=0;arg_opts[j].name!=NULL;j++)
+					if (g_strncasecmp(argv[i]+2,arg_opts[j].name,
+						MIN(strlen(argv[i])-2,strlen(arg_opts[j].name)))==0) {
+						opt=arg_opts[j].key;
+						break;
+					}
+			} else {					/* ûץ */
+				opt=tolower((argv[i])[1]);
+			}
+			arg=NULL;
+			for (j=0;arg_opts[j].name!=NULL;j++)
+				if (arg_opts[j].key==opt && arg_opts[j].arg!=NULL) {
+					for (k=2;(argv[i])[k]!='\0' && (argv[i])[k]!='=';k++);
+					arg=(argv[i])[k]=='\0'?argv[++i]:argv[i]+k+1;
+					if (arg==NULL || *arg=='\0')
+						opt='?';
+					break;
+				}
+			switch (opt) {
+				case 'h':
+					strval(&history,arg,10,TRUE);
+					if (history<0)
+						history=0;
+					else if (history>10)
+						history=10;
+					break;
+				case 'l':
+					strval(&init_line,arg,10,TRUE);
+					break;
+				case 'n':
+					newfile=g_strcasecmp(arg,"OK")==0
+												|| g_strcasecmp(arg,"TRUE")==0
+												|| g_strcasecmp(arg,"YES")==0;
+					break;
+				case 's':
+					def_height=strtol(arg,&endptr,0);
+					def_width=strtol(++endptr,&endptr,0);
+					break;
+				case 'v':
+					g_print(
+"Text maid "VERSION"\n"
+"Copyright (C) 1998-2002 Iwamoto,Kazuki\n"
+"This is free software; see the source for copying conditions.  There is NO\n"
+"warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
+					);
+					g_free(arg_files);
+					return 0;
+				default:
+					g_print(
+"Copyright (c) 1998-2002 Iwamoto,Kazuki\n\n"
+"Usage: %s [OPTION...] [FILE...]\n\n",argv[0]);
+					for (i=0;arg_opts[i].name;i++) {
+						if (arg_opts[i].arg!=NULL)
+							str=g_strdup_printf("  -%c, --%s=%s",
+											arg_opts[i].key,arg_opts[i].name,
+															arg_opts[i].arg);
+						else
+							str=g_strdup_printf("  -%c, --%s",
+											arg_opts[i].key, arg_opts[i].name);
+						g_print("%-26s %s\n",str,arg_opts[i].doc);
+						g_free(str);
+					}
+					g_print("\n");
+					g_free(arg_files);
+					return 0;
+			}
+		} else {/* ե */
+			arg_files[i]=TRUE;
+		}
+	}
 
 	/* ե륿 */
 	if (ftnum<=0) {
 		ftnum=2;
 		ftype=g_malloc(ftnum*sizeof(FTYPE));
 		ftype[0].text=g_strdup(_("ƥȥե"));
-		ftype[0].ext=g_strdup("txt");
+		ftype[0].ext=g_strdup(".txt");
 		ftype[1].text=g_strdup(_("٤ƤΥե"));
 		ftype[1].ext=g_strdup("*");
 		ftype[0].margin=ftype[1].margin=80;
@@ -340,13 +445,19 @@ int main(int argc,char *argv[])
 								GTK_SIGNAL_FUNC(signal_switch_page),NULL);
 	gtk_signal_connect(GTK_OBJECT(notebook),"destroy",
 								GTK_SIGNAL_FUNC(signal_destroy_notebook),NULL);
+	/* ݥåץå */
+	accel_group=gtk_accel_group_new();
+	item_factory_popup=gtk_item_factory_new(GTK_TYPE_MENU,"<main>",accel_group);
+	gtk_item_factory_create_items(item_factory_popup,
+			sizeof(popup_items)/sizeof(GtkItemFactoryEntry),popup_items,NULL);
 	/* ˥塼 */
 	accel_group=gtk_accel_group_new();
-	item_factory=gtk_item_factory_new(GTK_TYPE_MENU_BAR,"<main>",accel_group);
-	gtk_item_factory_create_items(item_factory,
+	item_factory_menu=gtk_item_factory_new(GTK_TYPE_MENU_BAR,
+														"<main>",accel_group);
+	gtk_item_factory_create_items(item_factory_menu,
 			sizeof(menu_items)/sizeof(GtkItemFactoryEntry),menu_items,NULL);
 	gtk_accel_group_attach(accel_group,GTK_OBJECT(window));
-	menubar=gtk_item_factory_get_widget(item_factory,"<main>");
+	menubar=gtk_item_factory_get_widget(item_factory_menu,"<main>");
 	/* ġС */
 	toolbar=gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL,GTK_TOOLBAR_ICONS);
 	for (i=0;i<18;i++)
@@ -370,7 +481,8 @@ int main(int argc,char *argv[])
 	gtk_box_pack_start(GTK_BOX(vbox),notebook,TRUE,TRUE,0);
 	gtk_box_pack_end(GTK_BOX(vbox),status,FALSE,FALSE,0);
 	/* ե */
-	sub_menu=gtk_item_factory_get_widget(item_factory,_("<main>/ե(F)"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
+													_("<main>/ե(F)"));
 	for (i=0;i<history && hisfile[i]!=NULL;i++) {
 		menu_item=gtk_menu_item_new_with_label(hisfile[i]);
 		gtk_signal_connect(GTK_OBJECT(menu_item),"activate",
@@ -393,10 +505,16 @@ int main(int argc,char *argv[])
 	gtk_window_set_policy(GTK_WINDOW(window),TRUE,TRUE,TRUE);
 
 	/* ɥ */
-	if (remaining==argc && newfile)
+	for (i=1;i<argc;i++)
+		if (arg_files[i]) {
+			ptw=open_edit_file(argv[i]);
+			if (init_line!=0)	/* Ԥ˰ư */
+				jump_operation(ptw,init_line);
+			newfile=FALSE;
+		}
+	g_free(arg_files);
+	if (newfile)
 		open_edit_file(NULL);
-	while (remaining<argc)
-		open_edit_file(argv[remaining++]);
 
 	gtk_main();
 
